#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.in_interfaces.camera_3d import Camera3D
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.tps_interfaces.tps_view import TPSView
from pycatia.tps_interfaces.tps_views import TPSViews
from pycatia.tps_interfaces.tps_parallel_on_screen import TPSParallelOnScreen

if TYPE_CHECKING:
    from pycatia.tps_interfaces.annotations import Annotations
    from pycatia.tps_interfaces.annotation_set import AnnotationSet


class Capture(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Capture
                | 
                | The interface to access a CATIACapture
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.capture = com_object

    @property
    def active_view(self) -> TPSView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveView() As TPSView
                | 
                |     Retrieves the active view for the capture.

        :return: TPSView
        :rtype: TPSView
        """

        return TPSView(self.capture.ActiveView)

    @active_view.setter
    def active_view(self, value: TPSView):
        """
        :param TPSView value:
        """

        self.capture.ActiveView = value

    @property
    def active_view_state(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveViewState() As boolean
                | 
                |     Retrieves the Active View state, saved or Not. The Active View state
                |     describes what happens when Capture is displayed, if TRUE, the active view of
                |     the tolerancing set is replaced by the active view of the capture.

        :return: bool
        :rtype: bool
        """

        return self.capture.ActiveViewState

    @active_view_state.setter
    def active_view_state(self, value: bool):
        """
        :param bool value:
        """

        self.capture.ActiveViewState = value

    @property
    def annotations(self) -> 'Annotations':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Annotations() As Annotations
                | 
                |     Retrieves the TPSs that are visualy managed by this Capture.

        :return: Annotations
        :rtype: Annotations
        """
        from pycatia.tps_interfaces.annotations import Annotations
        return Annotations(self.capture.Annotations)

    @annotations.setter
    def annotations(self, value: 'Annotations'):
        """
        :param Annotations value:
        """

        self.capture.Annotations = value

    @property
    def camera(self) -> Camera3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Camera() As Camera3D
                | 
                |     Retrieves or sets a camera.

        :return: Camera3D
        :rtype: Camera3D
        """

        return Camera3D(self.capture.Camera)

    @camera.setter
    def camera(self, value: Camera3D):
        """
        :param Camera3D value:
        """

        self.capture.Camera = value

    @property
    def clipping_plane(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ClippingPlane() As boolean
                | 
                |     Retrieves the clipping plane state, activated or Not. The Clipping plane
                |     state describes what happens when Capture is displayed, if TRUE, the active
                |     view is used to define a clipping plane. If FALSE, there is no clipping plane
                |     applied.
                | 
                |     Parameters:
                | 
                |         oClipPlane
                |             The clipping plane state.

        :return: bool
        :rtype: bool
        """

        return self.capture.ClippingPlane

    @clipping_plane.setter
    def clipping_plane(self, value: bool):
        """
        :param bool value:
        """

        self.capture.ClippingPlane = value

    @property
    def current(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Current() As boolean
                | 
                |     Retrieves the Capture state, current or Not.
                | 
                |     Parameters:
                | 
                |         oCurrentState
                |             Capture state. if TRUE the capture is current.that means that after
                |             the creation of the capture, the future TPSs that would be added to the
                |             document will belong to the capture.

        :return: bool
        :rtype: bool
        """

        return self.capture.Current

    @current.setter
    def current(self, value: bool):
        """
        :param bool value:
        """

        self.capture.Current = value

    @property
    def manage_hide_show_body(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ManageHideShowBody() As boolean
                | 
                |     Manages the visibility of Part instances, bodies and geometrical sets
                |     across the Capture.
                | 
                |     Parameters:
                | 
                |         obManageHideShowBody
                |             TRUE: If Hide/Show of these elements will be managed FALSE: If
                |             Hide/Show of these elements will not be managed

        :return: bool
        :rtype: bool
        """

        return self.capture.ManageHideShowBody

    @manage_hide_show_body.setter
    def manage_hide_show_body(self, value: bool):
        """
        :param bool value:
        """

        self.capture.ManageHideShowBody = value

    @property
    def set(self) -> 'AnnotationSet':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Set() As AnnotationSet (Read Only)
                | 
                |     Retrieves tolerancing set the Capture belongs too.

        :return: AnnotationSet
        :rtype: AnnotationSet
        """
        from pycatia.tps_interfaces.annotation_set import AnnotationSet
        return AnnotationSet(self.capture.Set)

    @property
    def tps_views(self) -> TPSViews:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TPSViews() As TPSViews
                | 
                |     Retrieves the TPS Views that are visualy managed by this Capture.

        :return: TPSViews
        :rtype: TPSViews
        """

        return TPSViews(self.capture.TPSViews)

    @tps_views.setter
    def tps_views(self, value: TPSViews):
        """
        :param TPSViews value:
        """

        self.capture.TPSViews = value

    @property
    def view_point(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewPoint() As boolean
                | 
                |     Retrieves the ViewPoint state, saved or Not. The ViewPoint state describes
                |     what happens when Capture is displayed, if TRUE, the 3D Camera of the Capture
                |     is used to change the 3D ViewPoint.

        :return: bool
        :rtype: bool
        """

        return self.capture.ViewPoint

    @view_point.setter
    def view_point(self, value: bool):
        """
        :param bool value:
        """

        self.capture.ViewPoint = value

    def display_capture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DisplayCapture()
                | 
                |     Displays the Capture.

        :return: None
        :rtype: None
        """
        return self.capture.DisplayCapture()

    def display_capture_2(self, ib_apply_mirror: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DisplayCapture2(boolean ibApplyMirror)
                | 
                |     Displays the Capture with mirroring annotations
                |     management.
                | 
                |     Parameters:
                | 
                |         out
                |             boolean ibApplyMirror [out] Annotations mirroring management: TRUE:
                |             The annotations mirroring is activated. FALSE: The annotations mirroring is
                |             desactivated.

        :param bool ib_apply_mirror:
        :return: None
        :rtype: None
        """
        return self.capture.DisplayCapture2(ib_apply_mirror)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'display_capture2'
        # # vba_code = """
        # # Public Function display_capture2(capture)
        # #     Dim ibApplyMirror (2)
        # #     capture.DisplayCapture2 ibApplyMirror
        # #     display_capture2 = ibApplyMirror
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def tps_parallel_on_screen(self) -> TPSParallelOnScreen:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TPSParallelOnScreen() As TPSParallelOnScreen
                | 
                |     Gets the annotation on TPSParallelOnScreen interface.

        :return: TPSParallelOnScreen
        :rtype: TPSParallelOnScreen
        """
        return TPSParallelOnScreen(self.capture.TPSParallelOnScreen())

    def __repr__(self):
        return f'Capture(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.drafting_interfaces.drawing_table import DrawingTable
from pycatia.system_interfaces.collection import Collection


class DrawingTables(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingTables
                | 
                | A collection of all the drawing tables currently managed by a drawing view of
                | drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingTable)
        self.drawing_tables = com_object

    def add(self,
            i_position_x: float,
            i_position_y: float,
            i_number_of_row: int,
            i_number_of_column: int,
            i_row_height: float,
            i_column_width: float) -> DrawingTable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(double iPositionX,
                | double iPositionY,
                | long iNumberOfRow,
                | long iNumberOfColumn,
                | double iRowHeight,
                | double iColumnWidth) As DrawingTable
                | 
                |     Creates a drawing table and adds it to the DrawingTables
                |     collection.
                | 
                |     Parameters:
                | 
                |         iPositionX,iPositionY
                |             The drawing table x and y coordinates, expressed in millimeters,
                |             with respect to the drawing view coordinate system
                |             
                |         iNumberOfRow,iNumberOfColumn
                |             The drawing table number of rows and columns 
                |         iRowHeight,iColumnWidth
                |             The row height and the column width 
                | 
                |     Returns:
                |         The created drawing table 
                | 
                | Example:
                |     The following example creates an empty drawing table and retrieves it in
                |     MyTable in the drawing table collection of the active view MyView of the
                |     drawing sheet MySheet.
                | 
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim MyTable As DrawingTable
                |      Set MyTable = MyView.Tables.Add(100., 100., 2, 2, 20., 50.)

        :param float i_position_x:
        :param float i_position_y:
        :param int i_number_of_row:
        :param int i_number_of_column:
        :param float i_row_height:
        :param float i_column_width:
        :return: DrawingTable
        :rtype: DrawingTable
        """
        return DrawingTable(
            self.drawing_tables.Add(
                i_position_x,
                i_position_y,
                i_number_of_row,
                i_number_of_column,
                i_row_height,
                i_column_width
            )
        )

    def item(self, i_index: int) -> DrawingTable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iIndex) As DrawingTable
                | 
                |     Returns a drawing table using its index from the DrawingTables
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing table to retrieve from the collection of
                |             drawing tables. As a numerics, this index is the rank of the drawing table in
                |             the collection. The index of the first drawing table in the collection is 1,
                |             and the index of the last drawing table is Count. 
                | 
                |     Returns:
                |         The retrieved drawing table 
                |     Example:
                |         This example retrieves in ThisDrawingTable the second drawing table, in
                |         the drawing view collection of the active view in the active sheet, in the
                |         active document supposed to be a drawing document.
                | 
                |          Dim MyView  As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          Dim ThisDrawingTable As DrawingTable
                |          Set ThisDrawingTable = MyView.Tables.Item(2)

        :param int i_index:
        :return: DrawingTable
        :rtype: DrawingTable
        """
        return DrawingTable(self.drawing_tables.Item(i_index))

    def remove(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(long iIndex)
                | 
                |     Removes a drawing table from the DrawingTables collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing table to remove from the collection of
                |             drawing tables. As a numerics, this index is the rank of the drawing table in
                |             the collection. The index of the first drawing table in the collection is 1,
                |             and the index of the last drawing table is Count. 
                | 
                |     Example:
                |         The following example removes the third drawing table in the drawing
                |         table collection of the active view of the active document, supposed to be a
                |         drawing document.
                | 
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          MyView.DrawingTables.Remove(3)

        :param int i_index:
        :return: None
        """
        return self.drawing_tables.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingTable:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingTable(self.drawing_tables.item(n + 1))

    def __iter__(self) -> Iterator[DrawingTable]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'DrawingTables(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.knowledge_interfaces.knowledge_activate_object import KnowledgeActivateObject
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.knowledge_interfaces.parameter import Parameter

class Relation(KnowledgeActivateObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             Relation
                | 
                | Represents the relation object.
                | It is an abstract object which is not intended to be created as such, but from
                | which the check, design table, formula, rule, objects derive.
                | 
                | See also:
                |     Check, DesignTable, Formula, Rule
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.relation = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Comment() As CATBSTR
                | 
                |     Returns or sets the comment associated with the relation. The comment
                |     explains the relation's purpose. It is passed as the second input argument of
                |     the relation creation methods of the Relations collection.
                | 
                |     Example:
                |         This example retrieves the maximummass relation comment and displays it
                |         in a message box:
                | 
                |          relcomment = maximummass.Comment
                |          MsgBox "maximummass comment : " & relcomment

        :return: str
        :rtype: str
        """

        return self.relation.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.relation.Comment = value

    @property
    def context(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Context() As AnyObject (Read Only)
                | 
                |     Returns the context of the parameter.
                |     The context of a parameter can be a part, a product, a drafting, or a
                |     process document, depending where the parameter is.
                | 
                |     Returns:
                |         The context 
                |     See also:
                |         Part, Product, CATIADrawing, CATIAProcess

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.relation.Context)

    @property
    def nb_in_parameters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbInParameters() As long (Read Only)
                | 
                |     Returns the number of input parameters of the relation.

        :return: int
        :rtype: int
        """

        return self.relation.NbInParameters

    @property
    def nb_out_parameters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property NbOutParameters() As long (Read Only)
                | 
                |     Returns the number of output parameters of the relation.
                |     The output parameters of the relation are those constrained by the
                |     relation.

        :return: int
        :rtype: int
        """

        return self.relation.NbOutParameters

    @property
    def value(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Value() As CATBSTR (Read Only)
                | 
                |     Returns the definition of the relation. It returns an empty string if the
                |     relation is not an expressional one (for example for a design table). The
                |     definition is the body to be executed to compute one or several parameters. It
                |     is passed as the last input argument of the relation creation methods of the
                |     Relations collection.
                | 
                |     Example:
                |         This example retrieves the maximummass relation definition and displays
                |         it in a message box:
                | 
                |          reldef = maximummass.Value
                |          MsgBox "maximummass relation is defined as " & reldef

        :return: str
        :rtype: str
        """

        return self.relation.Value

    def get_in_parameter(self, i_index: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetInParameter(long iIndex) As AnyObject
                | 
                |     Returns an input parameter of the relation.
                |     This method can return an object that is not a parameter, that is, you
                |     cannot handle it as a Parameter object. For example, in a relation
                |     like
                | 
                |     Area.1 = area(PartBody/Pad.1/Sketch.1)
                | 
                |     the object PartBody/Pad.1/Sketch.1 is a sketch and not a
                |     parameter.
                |     To use such an object, call the Visual Basic TypeName function to retrieve
                |     its real type.
                | 
                |     Dim objectType
                |      objectType = TypeName(oParameter)
                |      If objectType = "Parameter" Then
                |      ...
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The searched input parameter index in the
                |             relation.
                |             Legal values: 1 ≤ iIndex ≤ 
                | 
                |         NbInParameters

        :param int i_index:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnyObject(self.relation.GetInParameter(i_index))

    def get_out_parameter(self, i_index: int) -> 'Parameter':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetOutParameter(long iIndex) As Parameter
                | 
                |     Returns an output parameter of the relation. Use TypeName method on the
                |     returned parameter to get the real type of the parameter.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The searched input parameter index in the
                |             relation.
                |             Legal values: 1 ≤ iIndex ≤ 
                | 
                |         NbOutParameters

        :param int i_index:
        :return: Parameter
        :rtype: Parameter
        """
        from pycatia.knowledge_interfaces.parameter import Parameter
        return Parameter(self.relation.GetOutParameter(i_index))

    def modify(self, i_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Modify(CATBSTR iValue)
                | 
                |     Modifies the relation.
                | 
                |     Parameters:
                | 
                |         iValue
                |             The new relation value

        :param str i_value:
        :return: None
        :rtype: None
        """
        return self.relation.Modify(i_value)

    def rename(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Rename(CATBSTR iName)
                | 
                |     Renames the relation.
                | 
                |     Parameters:
                | 
                |         iName
                |             The new relation name

        :param str i_name:
        :return: None
        :rtype: None
        """
        return self.relation.Rename(i_name)

    def __repr__(self):
        return f'Relation(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeFilletTriTangent(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeFilletTriTangent
                | 
                | Fillet Tri-Tangent feature.
                | Role: Manipulation of Fillet Tri-Tangent feature Allows to access data of the
                | Fillet Tri-Tangent feature created by using three support surfaces, their
                | orientation, and options (supports trimming and fillet extremities
                | type)
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_fillet_tri_tangent = com_object

    @property
    def first_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstElem() As Reference
                | 
                |     Returns or sets the first support surface feature.
                | 
                |     Example:
                |         This example retrieves in FirstElem the first support element used by
                |         the HybShpFilletTriTangent hybrid shape feature.
                | 
                |          Dim FirstElem As Reference 
                |          Set FirstElem = HybShpFilletTriTangent.FirstElem

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_fillet_tri_tangent.FirstElem)

    @first_elem.setter
    def first_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_fillet_tri_tangent.FirstElem = reference_element.com_object

    @property
    def first_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstOrientation() As long
                | 
                |     Returns or sets the first orientation used to specify fillet center
                |     position.
                |     Note; Orientation is same or inverse than the normal to the first surface
                |     support

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_fillet_tri_tangent.FirstOrientation

    @first_orientation.setter
    def first_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fillet_tri_tangent.FirstOrientation = value

    @property
    def remove_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RemoveElem() As Reference
                | 
                |     Returns or sets the support surface to remove feature.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_fillet_tri_tangent.RemoveElem)

    @remove_elem.setter
    def remove_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_fillet_tri_tangent.RemoveElem = reference_element.com_object

    @property
    def remove_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RemoveOrientation() As long
                | 
                |     Returns or sets the third orientation used to specify fillet center
                |     position.
                |     note: Orientation is same or inverse than the normal to the surface support
                |     to remove

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_fillet_tri_tangent.RemoveOrientation

    @remove_orientation.setter
    def remove_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fillet_tri_tangent.RemoveOrientation = value

    @property
    def ribbon_relimitation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RibbonRelimitationMode() As long
                | 
                |     Returns or sets fillet ribbon relimitation mode (or fillet extremities
                |     mode).
                |     note: Smooth(0) or Straight(1) or Maximum(2) or Minimum(3)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_fillet_tri_tangent.RibbonRelimitationMode

    @ribbon_relimitation_mode.setter
    def ribbon_relimitation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fillet_tri_tangent.RibbonRelimitationMode = value

    @property
    def second_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondElem() As Reference
                | 
                |     Returns or sets the Second support surface feature.
                | 
                |     Example:
                |         This example retrieves in SecondElem the Second support element used by
                |         the HybShpFilletTriTangent hybrid shape feature.
                | 
                |          Dim SecondElem As Reference 
                |          Set SecondElem = HybShpFilletTriTangent.SecondElem
                |          
                | 
                |     Parameters:
                | 
                |         oElem
                |             Second support surface feature.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_fillet_tri_tangent.SecondElem)

    @second_elem.setter
    def second_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_fillet_tri_tangent.SecondElem = reference_element.com_object

    @property
    def second_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondOrientation() As long
                | 
                |     Returns or sets the Second orientation used to specify fillet center
                |     position.
                |     note: Orientation is same or inverse than the normal to the Second surface
                |     support

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_fillet_tri_tangent.SecondOrientation

    @second_orientation.setter
    def second_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fillet_tri_tangent.SecondOrientation = value

    @property
    def supports_trim_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SupportsTrimMode() As long
                | 
                |     Returns or sets whether support surfaces are trimmed or
                |     not.
                |     Trim (1) or NoTrim(0)
                |     note: if "Trim" the 2 supports are trimmed and assembled with the fillet
                |     ribbon.

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_fillet_tri_tangent.SupportsTrimMode

    @supports_trim_mode.setter
    def supports_trim_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_fillet_tri_tangent.SupportsTrimMode = value

    def invert_first_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertFirstOrientation()
                | 
                |     Inverts first orientation used to specify fillet center position.

        :return: None
        :rtype: None
        """
        return self.hybrid_shape_fillet_tri_tangent.InvertFirstOrientation()

    def invert_remove_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertRemoveOrientation()
                | 
                |     Inverts third orientation used to specify fillet center position.

        :return: None
        :rtype: None
        """
        return self.hybrid_shape_fillet_tri_tangent.InvertRemoveOrientation()

    def invert_second_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertSecondOrientation()
                | 
                |     Inverts second orientation used to specify fillet center position.

        :return: None
        :rtype: None
        """
        return self.hybrid_shape_fillet_tri_tangent.InvertSecondOrientation()

    def __repr__(self):
        return f'HybridShapeFilletTriTangent(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class OriginElements(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     OriginElements
                | 
                | Represents the part's 3D reference axis system.
                | It allows an easy access to 3D reference axis system of a Part object thru the
                | three planes XY, YZ, and ZX.
                | See Part for parent object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.origin_elements = com_object

    @property
    def plane_xy(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneXY() As AnyObject (Read Only)
                | 
                |     Returns the XY plane of the part 3D reference axis system.
                | 
                |     Example:
                |         The following example returns in plnXY the XY plane of the partRoot
                |         part from the partDoc part document:
                | 
                |          Set partRoot = partDoc.Part
                |          Set plnXY = partRoot.originElements.PlaneXY

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.origin_elements.PlaneXY)

    @property
    def plane_yz(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneYZ() As AnyObject (Read Only)
                | 
                |     Returns the YZ plane of the part 3D reference axis system.
                | 
                |     Example:
                |         The following example returns in plnYZ the YZ plane of the partRoot
                |         part from the partDoc part document:
                | 
                |          Set partRoot = partDoc.Part
                |          Set plnYZ = partRoot.originElements.PlaneYZ

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.origin_elements.PlaneYZ)

    @property
    def plane_zx(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneZX() As AnyObject (Read Only)
                | 
                |     Returns the ZX plane of the part 3D reference axis system.
                | 
                |     Example:
                |         The following example returns in plnZX the ZX plane of the partRoot
                |         part from the partDoc part document:
                | 
                |          Set partRoot = partDoc.Part
                |          Set plnZX = partRoot.originElements.PlaneZX

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.origin_elements.PlaneZX)

    def __repr__(self):
        return f'OriginElements(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCombine(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCombine
                | 
                | Represents the hybrid shape combined curve object.
                | Role: To access the data of the hybrid shape combined curve object. This data
                | includes:
                | 
                |     The three curves to which the circle is tangent
                |     The surface that supports the circle
                |     The orientation of each curve.
                | 
                | Use the HybridShapeFactory object to create a HybridShapeCombine
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_combine = com_object

    @property
    def direction1(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction1() As HybridShapeDirection
                | 
                |     Returns or sets the first direction used to create the combined curve. The
                |     first direction is the direction along which the first curve is
                |     extruded.
                | 
                |     Example:
                | 
                |           This example sets firstDir as the first direction to create the
                |           combined curve
                |          hybCombCurve.
                |          
                | 
                |          hybCombCurve.Direction1 = firstDir

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_combine.Direction1)

    @direction1.setter
    def direction1(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_combine.Direction1 = direction.com_object

    @property
    def direction2(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Direction2() As HybridShapeDirection
                | 
                |     Returns or sets the second direction used to create the combined
                |     curve.
                | 
                |     Example:
                | 
                |           This example retrieves in secondDir the second direction
                |           used
                |          to create the combined curve hybCombCurve.
                |          
                | 
                |          Dim secondDir As CATIAHybridShapeDirection
                |          Set secondDir = hybCombCurve.Direction2

        :return: HybridShapeDirection
        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_combine.Direction2)

    @direction2.setter
    def direction2(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_combine.Direction2 = direction.com_object

    @property
    def elem1(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Elem1() As Reference
                | 
                |     Returns or sets the first curve used to create the combined
                |     curve.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example:
                | 
                |           This example sets firstCurve as the first curve to create the
                |           combined curve
                |          hybCombCurve.
                |          
                | 
                |          hybCombCurve.Elem1 = firstCurve

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_combine.Elem1)

    @elem1.setter
    def elem1(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_combine.Elem1 = reference_element.com_object

    @property
    def elem2(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Elem2() As Reference
                | 
                |     Returns or sets the second curve used to create the combined
                |     curve.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example:
                | 
                |           This example retrieves in secondCurve the second curve used to
                |           create
                |          the combined curve hybCombCurve.
                |          
                | 
                |          Dim secondCurve As CATIAReference
                |          Set secondCurve = hybCombCurve.Elem2

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_combine.Elem2)

    @elem2.setter
    def elem2(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_combine.Elem2 = reference_element.com_object

    @property
    def nearest_solution(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NearestSolution() As long
                | 
                |     Returns or sets whether the combined curve is or should be created as the
                |     curve closest to the first curve.
                |     Role: The nearest solution indicates whether the created combined curve is
                |     the one closest to the first curve if there are several possible combined
                |     curves, or if all these possible combined curves are
                |     created..
                |     Legal values: 0 for the nearest solution and 1 for all possible
                |     solutions.
                | 
                |     Example:
                | 
                |           This example sets the nearest solution mode to create the combined
                |           curve
                |          hybCombCurve closest to the first curve.
                |          
                | 
                |          hybCombCurve.NearestSolution = 1

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_combine.NearestSolution

    @nearest_solution.setter
    def nearest_solution(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_combine.NearestSolution = value

    @property
    def solution_type_combine(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolutionTypeCombine() As long
                | 
                |     Returns or sets whether the curves that create the combined curve are or
                |     should be extruded along normals to the curve planes or along given
                |     directions.
                |     Role: The curves that make up the combined curve are each extruded along a
                |     direction. This direction can be the normal to the curve plane, or can be set
                |     to a given direction. This is valid for the two curves
                |     altogether.
                |     Legal values: 0 for the normal to the curve planes (default mode), 1 for
                |     given directions
                | 
                |     Example:
                | 
                |           This example sets that the combined curve hybCombCurve should be
                |           created
                |          by extruding the two curves along the normals to their
                |          planes.
                |          
                | 
                |          hybCombCurve.SolutionTypeCombine = 0

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_combine.SolutionTypeCombine

    @solution_type_combine.setter
    def solution_type_combine(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_combine.SolutionTypeCombine = value

    def __repr__(self):
        return f'HybridShapeCombine(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeHelix(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeHelix
                | 
                | Represents the hybrid shape helix feature object.
                | Role: Allows to access data of the Helix feature. This data
                | includes:
                | 
                |     axis
                |     a starting point
                |     a pitch
                |     a height
                |     2 angle values
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_helix = com_object

    @property
    def axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As Reference
                | 
                |     Reads / Changes the Helix axis.
                | 
                |     Parameters:
                | 
                |         Axis
                |             Helix axis.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): CATIARectlinearTriDimFeatEdge or
                |         RectilinearBiDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_helix.Axis)

    @axis.setter
    def axis(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_helix.Axis = reference_axis.com_object

    @property
    def clockwise_revolution(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ClockwiseRevolution() As boolean
                | 
                |     Reads / Modifies the sense of revolutions .
                | 
                |     Parameters:
                | 
                |         Clockwise
                |             FALSE means that revolutions are counter-clockwise. TRUE means that
                |             revolutions are clockwise.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_helix.ClockwiseRevolution

    @clockwise_revolution.setter
    def clockwise_revolution(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_helix.ClockwiseRevolution = value

    @property
    def height(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Height() As Length (Read Only)
                | 
                |     Reads the height of the Helix.
                | 
                |     Parameters:
                | 
                |         oHeight
                |             Height.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_helix.Height)

    @property
    def invert_axis(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InvertAxis() As boolean
                | 
                |     Reads / Modifies the orientation .
                | 
                |     Parameters:
                | 
                |         Invert
                |             FALSE means that there is no invertion (natural orientation). TRUE
                |             to invert this orientation.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_helix.InvertAxis

    @invert_axis.setter
    def invert_axis(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_helix.InvertAxis = value

    @property
    def pitch(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Pitch() As Length (Read Only)
                | 
                |     Reads the pitch of the Helix.
                | 
                |     Parameters:
                | 
                |         oPitch
                |             Pitch.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_helix.Pitch)

    @property
    def pitch2(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Pitch2() As Length (Read Only)
                | 
                |     Reads the Helix pitch2.
                | 
                |     Parameters:
                | 
                |         Pitch2
                |             Pitch2 for Helix.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_helix.Pitch2)

    @property
    def pitch_law_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PitchLawType() As long
                | 
                |     Reads / Changes the Helix pitch law type.
                | 
                |     Parameters:
                | 
                |         LawType
                |             LawType for Helix.

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_helix.PitchLawType

    @pitch_law_type.setter
    def pitch_law_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_helix.PitchLawType = value

    @property
    def profile(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Profile() As Reference
                | 
                |     Reads / Changes the Helix profile.
                | 
                |     Parameters:
                | 
                |         Profile
                |             Profile for Helix.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_helix.Profile)

    @profile.setter
    def profile(self, reference_profile: Reference):
        """
        :param Reference reference_profile:
        """

        self.hybrid_shape_helix.Profile = reference_profile.com_object

    @property
    def revol_number(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RevolNumber() As RealParam (Read Only)
                | 
                |     Reads the revolution number of the Helix.
                | 
                |     Parameters:
                | 
                |         oNbRevol
                |             Revolutions.

        :return: RealParam
        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_helix.RevolNumber)

    @property
    def starting_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartingAngle() As Angle (Read Only)
                | 
                |     Reads the helix starting angle.
                | 
                |     Parameters:
                | 
                |         oStartingAngle
                |             Starting angle.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_helix.StartingAngle)

    @property
    def starting_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartingPoint() As Reference
                | 
                |     Reads / Changes the starting point of the Helix. The starting point must
                |     not be on the Helix axis.
                | 
                |     Parameters:
                | 
                |         StartingPoint
                |             Starting point.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Vertex.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_helix.StartingPoint)

    @starting_point.setter
    def starting_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_helix.StartingPoint = reference_point.com_object

    @property
    def taper_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TaperAngle() As Angle (Read Only)
                | 
                |     Reads the helix taper angle.
                | 
                |     Parameters:
                | 
                |         oTaperAngle
                |             Taper angle.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_helix.TaperAngle)

    @property
    def taper_outward(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TaperOutward() As boolean
                | 
                |     Reads / Modifies the taper angle sense of variation.
                | 
                |     Parameters:
                | 
                |         TaperOutward
                |             FALSE means that helix radius decreases. TRUE means that helix
                |             radius increases.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_helix.TaperOutward

    @taper_outward.setter
    def taper_outward(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_helix.TaperOutward = value

    def set_height(self, i_height: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetHeight(double iHeight)
                | 
                |     Sets the helix height.
                | 
                |     Parameters:
                | 
                |         iHeight
                |             Height.

        :param float i_height:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetHeight(i_height)

    def set_pitch(self, i_pitch: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPitch(double iPitch)
                | 
                |     Sets the helix pitch.
                | 
                |     Parameters:
                | 
                |         iPitch
                |             Pitch.

        :param float i_pitch:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetPitch(i_pitch)

    def set_pitch2(self, i_pitch2: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPitch2(double iPitch2)
                | 
                |     Changes the Helix pitch2 .
                | 
                |     Parameters:
                | 
                |         Pitch2
                |             Pitch2 for Helix.

        :param float i_pitch2:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetPitch2(i_pitch2)

    def set_revolution_number(self, i_nb_revol: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRevolutionNumber(double iNbRevol)
                | 
                |     Changes the Revolution Numbers.
                | 
                |     Parameters:
                | 
                |         NbRevol
                |             Number of revolutions for Helix.

        :param float i_nb_revol:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetRevolutionNumber(i_nb_revol)

    def set_starting_angle(self, i_starting_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetStartingAngle(double iStartingAngle)
                | 
                |     Sets the helix starting angle.
                | 
                |     Parameters:
                | 
                |         oTaperAngle
                |             Starting angle.

        :param float i_starting_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetStartingAngle(i_starting_angle)

    def set_taper_angle(self, i_taper_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTaperAngle(double iTaperAngle)
                | 
                |     Sets the helix taper angle.
                | 
                |     Parameters:
                | 
                |         iTaperAngle
                |             Taper angle.

        :param float i_taper_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_helix.SetTaperAngle(i_taper_angle)

    def __repr__(self):
        return f'HybridShapeHelix(name="{ self.name }")'



from typing import TypeVar, Type
from pycatia.knowledge_interfaces.bool_param import BoolParam
from pycatia.knowledge_interfaces.int_param import IntParam
from pycatia.knowledge_interfaces.str_param import StrParam
from pycatia.knowledge_interfaces.real_param import RealParam

"""
This is a doc comment.
"""

#: cat_variant The cat_variant type allows both int and string.
cat_variant = TypeVar('cat_variant', int, str)
list_str = TypeVar('list_str', list, str)
any_parameter = TypeVar('any_parameter', BoolParam, IntParam, StrParam, RealParam)



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapePolyline(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapePolyline
                | 
                | Represents the hybrid shape polyline curve object.
                | Role: To access or set the data of the hybrid shape polyline object. This data
                | includes:
                | 
                |     Elements
                |     Radius
                |     Closure
                | 
                | Use the HybridShapeFactory object to create a HybridShapePolyline
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_polyline = com_object

    @property
    def closure(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Closure() As boolean
                | 
                |     Returns or sets the flag to decide closure of the
                |     polyline.
                | 
                |     Parameters:
                | 
                |         Closure
                |             (For get_Closure) Returns or sets the closure
                |             property
                | 
                |             Example:
                |                 This example retrieves the closure property of the polyline of
                |                 the HybShpPolyline hybrid shape polyline.
                | 
                |                  Dim HybShpPolClosure As  boolean
                |                  HybShpPolClosure = HybShpPolyline.Closure

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_polyline.Closure

    @closure.setter
    def closure(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_polyline.Closure = value

    @property
    def number_of_elements(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NumberOfElements() As long (Read Only)
                | 
                |     Returns the number of elements of the polyline.
                | 
                |     Parameters:
                | 
                |         NumberOfElements
                |             Number of elements in the polyline.
                | 
                |             Example:
                |                 This example retrieves the number of elements in the polyline
                |                 of the HybShpPolyline hybrid shape polyline.
                | 
                |                  Dim HybShpPolNoOfEle As  long
                |                  HybShpPolNoOfEle = HybShpPolyline.NumberOfElements

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_polyline.NumberOfElements

    def get_element(self, i_position: int, o_element: Reference, o_radius: Length) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetElement(long iPosition,
                | Reference oElement,
                | Length oRadius)
                | 
                |     Returns the element of the polyline.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position at which the element is to be retrieved. 
                |         oElement
                |             Reference to the element. 
                |         ioRadius
                |             Length to the radius.
                | 
                |             Example:
                |                 This example retrieves the element and radius of the polyline
                |                 at specified position of the HybShpPolyline hybrid shape
                |                 polyline.
                | 
                |                  Dim HybShpPolylineElement As Reference
                |                  Dim HybShpPolylineRadius As Reference
                |                  HybShpPolyline.GetElement 1,
                |                  HybShpPolylineElement,HybShpPolylineRadius

        :param int i_position:
        :param Reference o_element:
        :param Length o_radius:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_polyline.GetElement(i_position, o_element.com_object, o_radius.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_element'
        # # vba_code = """
        # # Public Function get_element(hybrid_shape_polyline)
        # #     Dim iPosition (2)
        # #     hybrid_shape_polyline.GetElement iPosition
        # #     get_element = iPosition
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def insert_element(self, i_point: Reference, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertElement(Reference iPoint,
                | long iPosition)
                | 
                |     Inserts the element at a specified position in the
                |     polyline.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             Reference of the point object to be inserted. 
                |         iPosition
                |             Position at which the element should be inserted.
                | 
                |             Example:
                |                 This example inserts the element in the polyline of the
                |                 HybShpPolyline hybrid shape polyline.
                | 
                |                  HybShpPolyline.InsertElement PointReference,1

        :param Reference i_point:
        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_polyline.InsertElement(i_point.com_object, i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_element'
        # # vba_code = """
        # # Public Function insert_element(hybrid_shape_polyline)
        # #     Dim iPoint (2)
        # #     hybrid_shape_polyline.InsertElement iPoint
        # #     insert_element = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_element(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElement(long iPosition)
                | 
                |     Removes the element at a specified position in the
                |     polyline.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position from which the element should be should be
                |             removed.
                | 
                |             Example:
                |                 This example removes the element in the polyline of the
                |                 HybShpPolyline hybrid shape polyline.
                | 
                |                  HybShpPolyline.RemoveElement 1

        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_polyline.RemoveElement(i_position)

    def replace_element(self, i_point: Reference, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceElement(Reference iPoint,
                | long iPosition)
                | 
                |     Replaces the element at a specified position in the
                |     polyline.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             Reference of the point object that will replace the old element.
                |             
                |         iPosition
                |             Position at which the element should be inserted.
                | 
                |             Example:
                |                 This example replaces the element in the polyline of the
                |                 HybShpPolyline hybrid shape polyline.
                | 
                |                  HybShpPolyline.ReplaceElement PointReference, 1

        :param Reference i_point:
        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_polyline.ReplaceElement(i_point.com_object, i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_element'
        # # vba_code = """
        # # Public Function replace_element(hybrid_shape_polyline)
        # #     Dim iPoint (2)
        # #     hybrid_shape_polyline.ReplaceElement iPoint
        # #     replace_element = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_radius(self, i_position: int, i_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRadius(long iPosition,
                | double iRadius)
                | 
                |     Sets the radius at specified position of the polyline.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position at which radius should be set 
                |         iRadius
                |             Value of the radius to be set.
                | 
                |             Example:
                |                 This example sets the radius at the specific position of the
                |                 polyline of the HybShpPolyline hybrid shape
                |                 polyline.
                | 
                |                  HybShpPolyline.SetRadius 1, 10

        :param int i_position:
        :param float i_radius:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_polyline.SetRadius(i_position, i_radius)

    def __repr__(self):
        return f'HybridShapePolyline(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.dress_up_shape import DressUpShape


class Shell(DressUpShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             Shell
                | 
                | Represents the shell shape.
                | A shell shape is made up of a list of faces to process and two thickness
                | parameters.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shell = com_object

    @property
    def external_thickness(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExternalThickness() As Length (Read Only)
                | 
                |     Returns the shell external thickness.
                | 
                |     Example:
                |         The following example returns in extThick the external thickness of the
                |         shell firstShell:
                | 
                |          Set extThick = firstShell.ExternalThickness

        :return: Length
        :rtype: Length
        """

        return Length(self.shell.ExternalThickness)

    @property
    def faces_to_remove(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FacesToRemove() As References (Read Only)
                | 
                |     Returns the collection of faces to be removed by the shell
                |     process.
                | 
                |     Example:
                |         The following example returns in list the faces to be removed from the
                |         shell firstShell:
                | 
                |          Set list = firstShell.FacesToRemove

        :return: References
        :rtype: References
        """

        return References(self.shell.FacesToRemove)

    @property
    def internal_thickness(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InternalThickness() As Length (Read Only)
                | 
                |     Returns the shell internal thickness.
                | 
                |     Example:
                |         The following example returns in intThick the internal thickness of the
                |         shell firstShell:
                | 
                |          Set intThick = firstShell.InternalThickness

        :return: Length
        :rtype: Length
        """

        return Length(self.shell.InternalThickness)

    def add_face_to_remove(self, i_face_to_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToRemove(Reference iFaceToRemove)
                | 
                |     Adds a new face to those to be removed by the shell
                |     process.
                | 
                |     Parameters:
                | 
                |         iFaceToRemove
                |             The face to be removed
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to be removed in the shell
                |     firstShell:
                | 
                |      call firstShell.AddFaceToRemove(face)

        :param Reference i_face_to_remove:
        :return: None
        :rtype: None
        """
        return self.shell.AddFaceToRemove(i_face_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_remove'
        # # vba_code = """
        # # Public Function add_face_to_remove(shell)
        # #     Dim iFaceToRemove (2)
        # #     shell.AddFaceToRemove iFaceToRemove
        # #     add_face_to_remove = iFaceToRemove
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_face_with_different_thickness(self, i_face_to_thicken: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceWithDifferentThickness(Reference
                | iFaceToThicken)
                | 
                |     Adds a new face to be thicken with different offset
                |     values.
                | 
                |     Parameters:
                | 
                |         iFaceToThicken
                |             The face to be thicken with different offset
                |             values
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to be thicken with different
                |     offset values in the shell firstShell:
                | 
                |      call firstShell.AddFaceWithDifferentThickness(face)

        :param Reference i_face_to_thicken:
        :return: None
        :rtype: None
        """
        return self.shell.AddFaceWithDifferentThickness(i_face_to_thicken.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_with_different_thickness'
        # # vba_code = """
        # # Public Function add_face_with_different_thickness(shell)
        # #     Dim iFaceToThicken (2)
        # #     shell.AddFaceWithDifferentThickness iFaceToThicken
        # #     add_face_with_different_thickness = iFaceToThicken
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_face_with_different_thickness(self, i_face_to_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFaceWithDifferentThickness(Reference
                | iFaceToRemove)
                | 
                |     Removes an existing face from those to be thicken with different offset
                |     values by the shell process.
                | 
                |     Parameters:
                | 
                |         iFaceToRemove
                |             The face to be removed from the shell
                |             specifications
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example removes the face face from the list of faces in the
                |     shell firstShell:
                | 
                |      call firstShell.RemoveFaceWithDifferentThickness(face)

        :param Reference i_face_to_remove:
        :return: None
        :rtype: None
        """
        return self.shell.RemoveFaceWithDifferentThickness(i_face_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_face_with_different_thickness'
        # # vba_code = """
        # # Public Function remove_face_with_different_thickness(shell)
        # #     Dim iFaceToRemove (2)
        # #     shell.RemoveFaceWithDifferentThickness iFaceToRemove
        # #     remove_face_with_different_thickness = iFaceToRemove
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_volume_support(self, i_volume_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetVolumeSupport(Reference iVolumeSupport)
                | 
                |     Set the Support Volume of the faces to modify during Shell operation.

        :param Reference i_volume_support:
        :return: None
        :rtype: None
        """
        return self.shell.SetVolumeSupport(i_volume_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_volume_support'
        # # vba_code = """
        # # Public Function set_volume_support(shell)
        # #     Dim iVolumeSupport (2)
        # #     shell.SetVolumeSupport iVolumeSupport
        # #     set_volume_support = iVolumeSupport
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_remove(self, i_face_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToRemove(Reference iFaceToWithdraw)
                | 
                |     Withdraws an existing face from those to be removed by the shell
                |     process.
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to be withdrawn from the shell
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example removes the face face from the list of faces in the
                |     shell firstShell:
                | 
                |      call firstShell.WithdrawFaceToRemove(face)

        :param Reference i_face_to_withdraw:
        :return: None
        :rtype: None
        """
        return self.shell.WithdrawFaceToRemove(i_face_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_remove'
        # # vba_code = """
        # # Public Function withdraw_face_to_remove(shell)
        # #     Dim iFaceToWithdraw (2)
        # #     shell.WithdrawFaceToRemove iFaceToWithdraw
        # #     withdraw_face_to_remove = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Shell(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class Marker3D(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Marker3D
                | 
                | Represents a marker 3D.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.marker_3d = com_object

    @property
    def fill(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Fill() As long
                | 
                |     Returns or sets the marker 3D's filling status (1 the figure is filled, 0
                |     the figure is not filled).
                | 
                |     Example:
                | 
                |              This example retrieves the filling status of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim status As Integer
                |             status = NewMarker3D.Fill

        :return: int
        :rtype: int
        """

        return self.marker_3d.Fill

    @fill.setter
    def fill(self, value: int):
        """
        :param int value:
        """

        self.marker_3d.Fill = value

    @property
    def frame(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Frame() As long
                | 
                |     Returns or sets the marker 3D's framing status (1 the figure is framed, 0
                |     the figure is not framed).
                | 
                |     Example:
                | 
                |              This example retrieves the framing status of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim status As Integer
                |             status = NewMarker3D.Frame

        :return: int
        :rtype: int
        """

        return self.marker_3d.Frame

    @frame.setter
    def frame(self, value: int):
        """
        :param int value:
        """

        self.marker_3d.Frame = value

    @property
    def text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Text() As CATBSTR
                | 
                |     Returns or sets the text for a text marker 3D.
                | 
                |     Example:
                | 
                |              This example reads the text of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim text As String
                |             text = NewMarker3D.Text

        :return: str
        :rtype: str
        """

        return self.marker_3d.Text

    @text.setter
    def text(self, value: str):
        """
        :param str value:
        """

        self.marker_3d.Text = value

    @property
    def text_font(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TextFont() As CATBSTR
                | 
                |     Returns or sets the text's font for a marker 3D.
                | 
                |     Example:
                | 
                |              This example retrieves the text's font of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim font As String
                |             font = NewMarker3D.TextFont

        :return: str
        :rtype: str
        """

        return self.marker_3d.TextFont

    @text_font.setter
    def text_font(self, value: str):
        """
        :param str value:
        """

        self.marker_3d.TextFont = value

    @property
    def text_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TextOrientation() As CatMarkerTextOrientation
                | 
                |     Returns or sets the orientation of text.
                | 
                |     Example:
                | 
                |              This example retrieves the orientation of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim orientation As CatMarkerTextOrientation
                |             orientation = NewMarker3D.TextOrientation

        :return: int
        :rtype: int
        """

        return self.marker_3d.TextOrientation

    @text_orientation.setter
    def text_orientation(self, value: int):
        """
        :param int value:
        """

        self.marker_3d.TextOrientation = value

    @property
    def text_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TextSize() As double
                | 
                |     Returns or sets the text's size for a marker 3D.
                | 
                |     Example:
                | 
                |              This example retrieves the text's size of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim size As Double
                |             size = NewMarker3D.TextSize

        :return: float
        :rtype: float
        """

        return self.marker_3d.TextSize

    @text_size.setter
    def text_size(self, value: float):
        """
        :param float value:
        """

        self.marker_3d.TextSize = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CatMarker3DType (Read Only)
                | 
                |     Returns the type of the marker 3D.
                | 
                |     Example:
                | 
                |              This example reads the type of NewMarker3D marker
                |              3D.
                |             
                | 
                |             Dim type As CatMarker3DType
                |             type = NewMarker3D.Type

        :return: int
        :rtype: int
        """

        return self.marker_3d.Type

    def add_object(self, i_object: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddObject(AnyObject iObject)
                | 
                |     Adds a link to an object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to be linked. 
                | 
                |     Example:
                | 
                |              This example links ThisProduct to the NewMarker3D marker
                |              3D.
                |             
                | 
                |             NewMarker3D.AddObject(ThisProduct)

        :param AnyObject i_object:
        :return: None
        :rtype: None
        """
        return self.marker_3d.AddObject(i_object.com_object)

    def count_object(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func CountObject() As long
                | 
                |     Returns the number of objects which are linked to the marker
                |     3D.
                | 
                |     Example:
                | 
                |              This example reads the number of objects in the marker3D
                |              NewMarker3D.
                |             
                | 
                |             Dim number As Integer
                |             number = NewMarker3D.CountObject

        :return: int
        :rtype: int
        """
        return self.marker_3d.CountObject()

    def get_object_positions(self, i_index: cat_variant, o_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetObjectPositions(CATVariant iIndex,
                | CATSafeArrayVariant oCoordinates)
                | 
                |     Retrieves the coordinates of the anchor point of the marker on the
                |     object.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the object in the marker 3D. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                |         oCoordinates
                |             The coordinates of the anchor point
                | 
                |                 oCoordinates(0) is the X coordinate of the anchor
                |                 point
                |                 oCoordinates(1) is the Y coordinate of the anchor
                |                 point
                |                 oCoordinates(2) is the Z coordinate of the anchor point
                |                 
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates of the anchor in the
                |              NewMarker3D marker 3D.
                |             
                | 
                |             Dim Coordinates (3)
                |             NewMarker3D.GetObjectPositions Coordinates

        :param cat_variant i_index:
        :param tuple o_coordinates:
        :return: None
        :rtype: None
        """
        return self.marker_3d.GetObjectPositions(i_index, o_coordinates)

    def get_text_positions(self, o_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetTextPositions(CATSafeArrayVariant oCoordinates)
                | 
                |     Retrieves the coordinates of the positions of a text marker 3D. The
                |     bottom-left corner of the text is anchored to a given
                |     point.
                | 
                |     Returns:
                |         The coordinates of the text anchor point
                | 
                |             oCoordinates(0) is the X coordinate of the text anchor
                |             point
                |             oCoordinates(1) is the Y coordinate of the text anchor
                |             point
                |             oCoordinates(2) is the Z coordinate of the text anchor point
                |             
                | 
                |     Example:
                | 
                |              This example retrieves the coordinates of the text in the
                |              NewMarker3D marker 3D.
                |             
                | 
                |             Dim Coordinates (2)
                |             NewMarker3D.GetTextPositions Coordinates

        :param tuple o_coordinates:
        :return: None
        :rtype: None
        """
        return self.marker_3d.GetTextPositions(o_coordinates)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_text_positions'
        # # vba_code = """
        # # Public Function get_text_positions(marker_3d)
        # #     Dim oCoordinates (2)
        # #     marker_3d.GetTextPositions oCoordinates
        # #     get_text_positions = oCoordinates
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item_object(self, i_index: cat_variant) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ItemObject(CATVariant iIndex) As CATBaseDispatch
                | 
                |     Returns an object which is linked to the marker 3D using its
                |     index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the object in the marker 3D. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                | 
                |     Returns:
                |         The retrieved object 
                |     Example:
                | 
                |              This example retrieves in ThisObject the ninth
                |              object
                |             from the NewMarker3D marker 3D.
                |             
                | 
                |             Dim ThisObject As Marker3D
                |             Set ThisObject = NewMarker3D.ItemObject(9)

        :param cat_variant i_index:
        :return: AnyObject
        :rtype: AnyObject
        """
        return self.marker_3d.ItemObject(i_index)

    def remove_object(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveObject(CATVariant iIndex)
                | 
                |     Removes an object which is linked to the marker 3D using its
                |     index.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the object in the marker 3D. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                | 
                |     Example:
                | 
                |              This example removes the ninth object
                |             from the NewMarker3D marker 3D.
                |             
                | 
                |             NewMarker3D.RemoveObject(9)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.marker_3d.RemoveObject(i_index)

    def set_object_positions(self, i_index: cat_variant, i_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetObjectPositions(CATVariant iIndex,
                | CATSafeArrayVariant iCoordinates)
                | 
                |     Sets the coordinates of the anchor point of the marker on the
                |     object.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the object in the marker 3D. The index of the first
                |             object is 1, and the index of the last object is CountObject.
                |             
                |         iCoordinates
                |             The coordinates of the anchor point
                | 
                |                 oCoordinates(0) is the X coordinate of the anchor
                |                 point
                |                 oCoordinates(1) is the Y coordinate of the anchor
                |                 point
                |                 oCoordinates(2) is the Z coordinate of the anchor point
                |                 
                | 
                |     Example:
                | 
                |              This example sets the coordinates of the anchor in the NewMarker3D
                |              marker 3D.
                |             
                | 
                |             Dim Coordinates (3)
                |             NewMarker3D.SetObjectPositions Coordinates

        :param cat_variant i_index:
        :param tuple i_coordinates:
        :return: None
        :rtype: None
        """
        return self.marker_3d.SetObjectPositions(i_index, i_coordinates)

    def set_text_positions(self, i_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTextPositions(CATSafeArrayVariant iCoordinates)
                | 
                |     Sets the coordinates of the positions of a text marker 3D.
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             The coordinates of the text anchor point
                | 
                |                 oCoordinates(0) is the X coordinate of the text anchor
                |                 point
                |                 oCoordinates(1) is the Y coordinate of the text anchor
                |                 point
                |                 oCoordinates(2) is the Z coordinate of the text anchor point
                |                 
                | 
                |     Example:
                | 
                |              This example sets the coordinates of the text in the NewMarker3D
                |              marker 3D.
                |             
                | 
                |             Dim Coordinates (2)
                |             NewMarker3D.SetTextPositions Coordinates

        :param tuple i_coordinates:
        :return: None
        :rtype: None
        """
        return self.marker_3d.SetTextPositions(i_coordinates)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_text_positions'
        # # vba_code = """
        # # Public Function set_text_positions(marker_3d)
        # #     Dim iCoordinates (2)
        # #     marker_3d.SetTextPositions iCoordinates
        # #     set_text_positions = iCoordinates
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Update()
                | 
                |     Updates the the marker 3D: that is to take into account all modifications
                |     which occur since last update.
                | 
                |     Example:
                | 
                |              This example updates the NewMarker3D marker 3D.
                |             
                | 
                |             NewMarker3D.Update

        :return: None
        :rtype: None
        """
        return self.marker_3d.Update()

    def __repr__(self):
        return f'Marker3D(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class PrintersSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         PrintersSettingAtt
                | 
                | Represents a setting controller for the printer settings.
                | Role: This interface is implemented by a component which represents the
                | controller of the printer settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.printers_setting_att = com_object

    def add_printer_directory(self, i_printer_dir: str, i_printer_dir_state: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddPrinterDirectory(CATBSTR iPrinterDir,
                | CatPrinterDirState iPrinterDirState)
                | 
                |     Add a printer file directory to printer directories list and define its
                |     state.
                | 
                |     Parameters:
                | 
                |         iPrinterDir
                |             directory where some 3DPLM printers are defined.
                |             The printers defined in this directory will be available for each
                |             user. 
                |         iPrinterDirState
                |             printer directory state.
                |             Each directory can be protected to prevent user access to the
                |             printers it contains.
                |             The state could be protect or free.
                |             If the state is CatPrinterDirProtect, the parameters of each
                |             printer included in the directory cannot be
                |             changed.
                |             If the state is CatPrinterDirFree, the parameters of each printer
                |             included in the directory can be changed, and the printers can be
                |             removed.
                |             Legal values:
                |             CatPrinterDirProtect : the printers included in the directory are protected.
                |             CatPrinterDirFree : the printers included in the directory are free.

        :param str i_printer_dir:
        :param int i_printer_dir_state:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.AddPrinterDirectory(i_printer_dir, i_printer_dir_state)

    def add_printer_group(self, i_printer_group_name: str, i_printer_names: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddPrinterGroup(CATBSTR iPrinterGroupName,
                | CATSafeArrayVariant iPrinterNames)
                | 
                |     Add a printer group and define the printers included in this
                |     group.
                | 
                |     Parameters:
                | 
                |         iPrinterGroupName
                |             printer group name 
                |         iPrinterNames
                |             array of printers included in the group.

        :param str i_printer_group_name:
        :param tuple i_printer_names:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.AddPrinterGroup(i_printer_group_name, i_printer_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_printer_group'
        # # vba_code = """
        # # Public Function add_printer_group(printers_setting_att)
        # #     Dim iPrinterGroupName (2)
        # #     printers_setting_att.AddPrinterGroup iPrinterGroupName
        # #     add_printer_group = iPrinterGroupName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_driver_configuration_path(self, o_driver_cfg_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDriverConfigurationPath(CATBSTR oDriverCfgPath)
                | 
                |     Returns the driver configuration file.
                | 
                |     Parameters:
                | 
                |         oDriverCfgPath
                |             path of the driver configuration file

        :param str o_driver_cfg_path:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.GetDriverConfigurationPath(o_driver_cfg_path)

    def get_driver_configuration_path_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDriverConfigurationPathInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the driver configuration
                |     file.
                |     Role: Retrieves the state of the driver configuration file in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         oAdminLevel
                |             If the parameter is locked, oAdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, oAdminLevel gives the
                |             administration level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.printers_setting_att.GetDriverConfigurationPathInfo(o_admin_level, o_locked)

    def get_new_printer_directory(self, o_new_printer_dir: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNewPrinterDirectory(CATBSTR oNewPrinterDir)
                | 
                |     Returns the directory where new printers will be added.
                | 
                |     Parameters:
                | 
                |         oNewPrinterDir
                |             directory to add new printers
                |             Role: Each new printer created by an user is added in this
                |             directory.

        :param str o_new_printer_dir:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.GetNewPrinterDirectory(o_new_printer_dir)

    def get_new_printer_directory_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNewPrinterDirectoryInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the directory where printers will be
                |     added.
                |     Role: Retrieves the state of the directory where printers will be added in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         oAdminLevel
                |             If the parameter is locked, oAdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, oAdminLevel gives the
                |             administration level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.printers_setting_att.GetNewPrinterDirectoryInfo(o_admin_level, o_locked)

    def get_printer_array_for_group(self, i_printer_group_name: str) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterArrayForGroup(CATBSTR iPrinterGroupName) As
                | CATSafeArrayVariant
                | 
                |     Returns the definition of the printer group.
                | 
                |     Parameters:
                | 
                |         iPrinterGroupName
                |             printer group name 
                | 
                |     Returns:
                |         array of printers included in the group.

        :param str i_printer_group_name:
        :return: tuple
        :rtype: tuple
        """
        return self.printers_setting_att.GetPrinterArrayForGroup(i_printer_group_name)

    def get_printer_directories(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterDirectories() As CATSafeArrayVariant
                | 
                |     Returns the directories of printer files.
                | 
                |     Returns:
                |         array of directories where 3DPLM printers are defined.

        :return: tuple
        :rtype: tuple
        """
        return self.printers_setting_att.GetPrinterDirectories()

    def get_printer_directories_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterDirectoriesInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the directories of printer files and
                |     their states.
                |     Role: Retrieves the state of the directories of printer files and their
                |     states in the current environment.
                | 
                |     Parameters:
                | 
                |         oAdminLevel
                |             If the parameter is locked, oAdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, oAdminLevel gives the
                |             administration level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.printers_setting_att.GetPrinterDirectoriesInfo(o_admin_level, o_locked)

    def get_printer_directory_state(self, i_printer_dir: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterDirectoryState(CATBSTR iPrinterDir) As
                | CatPrinterDirState
                | 
                |     Returns the state of the directory of printer files.
                | 
                |     Parameters:
                | 
                |         iPrinterDir
                |             directory where some 3DPLM printers are defined. 
                | 
                |     Returns:
                |         printer directory state.
                |         Each directory can be protected to prevent user access to the printers
                |         it contains.
                |         The state could be protect or free.
                |         If the state is CatPrinterDirProtect, the parameters of each printer
                |         included in the directory cannot be changed.
                |         If the state is CatPrinterDirFree, the parameters of each printer
                |         included in the directory can be changed, and the printers can be
                |         removed.
                |         Legal values:
                |         CatPrinterDirProtect : the printers included in the directory are protected.
                |         CatPrinterDirFree : the printers included in the directory are free.

        :param str i_printer_dir:
        :return: int
        :rtype: int
        """
        return self.printers_setting_att.GetPrinterDirectoryState(i_printer_dir)

    def get_printer_groups(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterGroups() As CATSafeArrayVariant
                | 
                |     Returns the printer groups.
                | 
                |     Returns:
                |         array of printer group names

        :return: tuple
        :rtype: tuple
        """
        return self.printers_setting_att.GetPrinterGroups()

    def get_printer_groups_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPrinterGroupsInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the definition of each printer
                |     group.
                |     Role: Retrieves the state of the definition of each printer group in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         oAdminLevel
                |             If the parameter is locked, oAdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, oAdminLevel gives the
                |             administration level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.printers_setting_att.GetPrinterGroupsInfo(o_admin_level, o_locked)

    def modify_printer_array_for_group(self, i_printer_group_name: str, i_printer_names: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ModifyPrinterArrayForGroup(CATBSTR iPrinterGroupName,
                | CATSafeArrayVariant iPrinterNames)
                | 
                |     Modify a printer group: redefine the array of printers included in this
                |     group.
                | 
                |     Parameters:
                | 
                |         iPrinterGroupName
                |             printer group name 
                |         iPrinterNames
                |             array of printers included in the group.

        :param str i_printer_group_name:
        :param tuple i_printer_names:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.ModifyPrinterArrayForGroup(i_printer_group_name, i_printer_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'modify_printer_array_for_group'
        # # vba_code = """
        # # Public Function modify_printer_array_for_group(printers_setting_att)
        # #     Dim iPrinterGroupName (2)
        # #     printers_setting_att.ModifyPrinterArrayForGroup iPrinterGroupName
        # #     modify_printer_array_for_group = iPrinterGroupName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def modify_printer_directory_state(self, i_printer_dir: str, i_printer_dir_state: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ModifyPrinterDirectoryState(CATBSTR iPrinterDir,
                | CatPrinterDirState iPrinterDirState)
                | 
                |     Modify a printer file directory state.
                | 
                |     Parameters:
                | 
                |         iPrinterDir
                |             directory where some 3DPLM printers are defined. 
                |         iPrinterDirState
                |             printer directory state.
                |             Each directory can be protected to prevent user access to the
                |             printers it contains.
                |             The state could be protect or free.
                |             If the state is CatPrinterDirProtect, the parameters of each
                |             printer included in the directory cannot be
                |             changed.
                |             If the state is CatPrinterDirFree, the parameters of each printer
                |             included in the directory can be changed, and the printers can be
                |             removed.
                |             Legal values:
                |             CatPrinterDirProtect : the printers included in the directory are protected.
                |             CatPrinterDirFree : the printers included in the directory are free.

        :param str i_printer_dir:
        :param int i_printer_dir_state:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.ModifyPrinterDirectoryState(i_printer_dir, i_printer_dir_state)

    def remove_all_printer_directories(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllPrinterDirectories()
                | 
                |     Remove all the directories including printer files.

        :return: None
        :rtype: None
        """
        return self.printers_setting_att.RemoveAllPrinterDirectories()

    def remove_all_printer_groups(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllPrinterGroups()
                | 
                |     Remove all the groups of printers.

        :return: None
        :rtype: None
        """
        return self.printers_setting_att.RemoveAllPrinterGroups()

    def remove_printer_directory(self, i_printer_dir: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemovePrinterDirectory(CATBSTR iPrinterDir)
                | 
                |     Remove a directory of printer files from the directories
                |     list.
                | 
                |     Parameters:
                | 
                |         iPrinterDir
                |             directory where some 3DPLM printers are defined.

        :param str i_printer_dir:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.RemovePrinterDirectory(i_printer_dir)

    def remove_printer_group(self, i_printer_group_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemovePrinterGroup(CATBSTR iPrinterGroupName)
                | 
                |     Remove a group of printers.
                | 
                |     Parameters:
                | 
                |         iPrinterGroupName
                |             name of the group to remove.

        :param str i_printer_group_name:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.RemovePrinterGroup(i_printer_group_name)

    def set_driver_configuration_path(self, i_driver_cfg_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDriverConfigurationPath(CATBSTR iDriverCfgPath)
                | 
                |     Sets the driver configuration file.
                | 
                |     Parameters:
                | 
                |         iDriverCfgPath
                |             path of the driver configuration file

        :param str i_driver_cfg_path:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetDriverConfigurationPath(i_driver_cfg_path)

    def set_driver_configuration_path_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDriverConfigurationPathLock(boolean iLock)
                | 
                |     Locks or unlocks the driver configuration file.
                |     Role: Locks or unlocks the driver configuration file if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed
                |             Legal values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_lock:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetDriverConfigurationPathLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_driver_configuration_path_lock'
        # # vba_code = """
        # # Public Function set_driver_configuration_path_lock(printers_setting_att)
        # #     Dim iLock (2)
        # #     printers_setting_att.SetDriverConfigurationPathLock iLock
        # #     set_driver_configuration_path_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_new_printer_directory(self, i_new_printer_dir: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetNewPrinterDirectory(CATBSTR iNewPrinterDir)
                | 
                |     Sets the directory where new printers will be added.
                | 
                |     Parameters:
                | 
                |         iNewPrinterDir
                |             directory to add new printers
                |             Role: Each new printer created by an user is added in this
                |             directory.

        :param str i_new_printer_dir:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetNewPrinterDirectory(i_new_printer_dir)

    def set_new_printer_directory_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetNewPrinterDirectoryLock(boolean iLock)
                | 
                |     Locks or unlocks the directory where printers will be
                |     added.
                |     Role: Locks or unlocks the directory where printers will be added if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed
                |             Legal values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_lock:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetNewPrinterDirectoryLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_new_printer_directory_lock'
        # # vba_code = """
        # # Public Function set_new_printer_directory_lock(printers_setting_att)
        # #     Dim iLock (2)
        # #     printers_setting_att.SetNewPrinterDirectoryLock iLock
        # #     set_new_printer_directory_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_printer_directories_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPrinterDirectoriesLock(boolean iLock)
                | 
                |     Locks or unlocks the directories of printer files and their
                |     states.
                |     Role: Locks or unlocks the directories of printer files and their states if
                |     it is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed
                |             Legal values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_lock:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetPrinterDirectoriesLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_printer_directories_lock'
        # # vba_code = """
        # # Public Function set_printer_directories_lock(printers_setting_att)
        # #     Dim iLock (2)
        # #     printers_setting_att.SetPrinterDirectoriesLock iLock
        # #     set_printer_directories_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_printer_groups_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPrinterGroupsLock(boolean iLock)
                | 
                |     Locks or unlocks the definition of each printer group.
                |     Role: Locks or unlocks the definition of each printer group if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed
                |             Legal values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_lock:
        :return: None
        :rtype: None
        """
        return self.printers_setting_att.SetPrinterGroupsLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_printer_groups_lock'
        # # vba_code = """
        # # Public Function set_printer_groups_lock(printers_setting_att)
        # #     Dim iLock (2)
        # #     printers_setting_att.SetPrinterGroupsLock iLock
        # #     set_printer_groups_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PrintersSettingAtt(name="{self.name}")'
